# AggregationKind


## Enum

* `DEFAULT` (value: `'default'`)

* `CUSTOM` (value: `'custom'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


